@@ -1,19 +1,7 @@
 /*  This file is part of the KDE project
- *    Copyright (C) 2010-2011 Lukas Tinkl <ltinkl@redhat.com>
+ *    SPDX-FileCopyrightText: 2010-2011 Lukas Tinkl <ltinkl@redhat.com>
  *
- *    This library is free software; you can redistribute it and/or
- *    modify it under the terms of the GNU Library General Public
- *    License version 2 as published by the Free Software Foundation.
- *
- *    This library is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *    Library General Public License for more details.
- *
- *    You should have received a copy of the GNU Library General Public License
- *    along with this library; see the file COPYING.LIB.  If not, write to
- *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *    Boston, MA 02110-1301, USA.
+ *    SPDX-License-Identifier: LGPL-2.0-only
  *
  */
 
@@ -21,8 +9,8 @@
 
 #include <powerdevil_debug.h>
 
-#include <QDir>
 #include <QDebug>
+#include <QDir>
 
 #include <KLocalizedString>
 
@@ -35,8 +23,8 @@
 #endif
 
 #ifdef USE_SYSCTL
-#include <sys/types.h>
 #include <sys/sysctl.h>
+#include <sys/types.h>
 
 #define HAS_SYSCTL(n) (sysctlbyname(n, nullptr, nullptr, nullptr, 0) == 0)
 #endif
@@ -44,7 +32,8 @@
 #define BACKLIGHT_SYSFS_PATH "/sys/class/backlight/"
 #define LED_SYSFS_PATH "/sys/class/leds/"
 
-BacklightHelper::BacklightHelper(QObject *parent) : QObject(parent)
+BacklightHelper::BacklightHelper(QObject *parent)
+    : QObject(parent)
 {
     init();
 }
@@ -203,8 +192,8 @@ void BacklightHelper::initUsingSysctl()
             if (!HAS_SYSCTL(qPrintable(QStringLiteral("hw.acpi.video.%1.active").arg(device)))) {
                 break;
             }
-            if (HAS_SYSCTL(qPrintable(QStringLiteral("hw.acpi.video.%1.brightness").arg(device))) &&
-                HAS_SYSCTL(qPrintable(QStringLiteral("hw.acpi.video.%1.levels").arg(device)))) {
+            if (HAS_SYSCTL(qPrintable(QStringLiteral("hw.acpi.video.%1.brightness").arg(device)))
+                && HAS_SYSCTL(qPrintable(QStringLiteral("hw.acpi.video.%1.levels").arg(device)))) {
                 m_sysctlDevice = device;
                 break;
             }
@@ -216,8 +205,7 @@ void BacklightHelper::initUsingSysctl()
     }
 
     size_t len;
-    if (sysctlbyname(qPrintable(QStringLiteral("hw.acpi.video.%1.levels").arg(m_sysctlDevice)), nullptr, &len, nullptr, 0) != 0 ||
-        len == 0) {
+    if (sysctlbyname(qPrintable(QStringLiteral("hw.acpi.video.%1.levels").arg(m_sysctlDevice)), nullptr, &len, nullptr, 0) != 0 || len == 0) {
         return;
     }
     int *levels = (int *)malloc(len);
@@ -381,9 +369,11 @@ ActionReply BacklightHelper::brightnessmax(const QVariantMap &args)
     }
 
     reply.addData(QStringLiteral("brightnessmax"), max_brightness);
-    //qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightnessmax"];
+    // qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightnessmax"];
 
     return reply;
 }
 
 KAUTH_HELPER_MAIN("org.kde.powerdevil.backlighthelper", BacklightHelper)
+
+#include "moc_backlighthelper.cpp"
