@@ -1,35 +1,22 @@
 /*  This file is part of the KDE project
- *    Copyright (C) 2010 Lukas Tinkl <ltinkl@redhat.com>
+ *    SPDX-FileCopyrightText: 2010 Lukas Tinkl <ltinkl@redhat.com>
  *
- *    This library is free software; you can redistribute it and/or
- *    modify it under the terms of the GNU Library General Public
- *    License version 2 as published by the Free Software Foundation.
- *
- *    This library is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *    Library General Public License for more details.
- *
- *    You should have received a copy of the GNU Library General Public License
- *    along with this library; see the file COPYING.LIB.  If not, write to
- *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *    Boston, MA 02110-1301, USA.
+ *    SPDX-License-Identifier: LGPL-2.0-only
  *
  */
 
-#ifndef BACKLIGHTHELPER_H
-#define BACKLIGHTHELPER_H
+#pragma once
 
 #include <QObject>
 #include <QVariantAnimation>
 
-#include <kauth_version.h>
 #include <KAuth/ActionReply>
 #include <KAuth/HelperSupport>
+#include <kauth_version.h>
 
 using namespace KAuth;
 
-class BacklightHelper: public QObject
+class BacklightHelper : public QObject
 {
     Q_OBJECT
 public:
@@ -70,5 +57,3 @@ private:
 
     QVariantAnimation m_anim;
 };
-
-#endif // BACKLIGHTHELPER_H
