@@ -1,37 +1,23 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
-
-#ifndef POWERDEVIL_POWERDEVILACTION_H
-#define POWERDEVIL_POWERDEVILACTION_H
+#pragma once
 
 #include "powerdevilpolicyagent.h"
 
 #include <QObject>
 #include <QVariantMap>
 
-class KConfigGroup;
+#include "powerdevilcore_export.h"
 
 namespace PowerDevil
 {
 class BackendInterface;
 class Core;
+class ProfileSettings;
 
 /**
  * @brief The base class for Power Management Actions
@@ -42,21 +28,17 @@ class Core;
  * @par Creating a brand new Action
  *
  * If you are already familiar with KDE's plugin system, you have to know that actions are
- * nothing but a KService plugin which will be loaded on demand. Each action has an ID associated to it
+ * nothing but a KCoreAddons plugin which will be loaded on demand. Each action has an ID associated to it
  * which represents it in the config file and uniquely identifies it in the loading phase.
  *
- * In addition to standard parameters, the .desktop file representing your action should contain the following
+ * In addition to standard parameters, the .json file representing your action should contain the following
  * entries:
  *
  * @code
- * X-KDE-PowerDevil-Action-ID=YourActionID
- * X-KDE-PowerDevil-Action-UIComponentLibrary=myactionplugin_config
- * X-KDE-PowerDevil-Action-ConfigPriority=98
+ * X-KDE-PowerDevil-Action-ID: YourActionID
+ * X-KDE-PowerDevil-Action-ConfigPriority: 98
  * @endcode
  *
- * The @c UIComponentLibrary field refers to the library which contains the configuration UI
- * for your action. Please see ActionConfig documentation for more details.
- *
  * The @c ConfigPriority is relevant to the configuration UI as well, and determines where your config UI will appear.
  * The higher the number, the higher your config UI will be in the list of actions. Choose this value wisely: usually
  * only very basic power management functions should have a value > 50.
@@ -70,20 +52,16 @@ class Core;
  *
  * Some actions might be available only when the system satisfies certain hardware or software runtime requirements.
  * In this case, powerdevil provides a way for the action to advertise to the outside whether it is supported or
- * not. This can be done by reimplementing @c isSupported and adding to the .desktop file the field
+ * not. This can be done by reimplementing @c isSupported and adding to the .json file the field
  *
  * @code
- * X-KDE-PowerDevil-Action-HasRuntimeRequirement=true
+ * X-KDE-PowerDevil-Action-HasRuntimeRequirement: true
  * @endcode
  *
  * Done that, powerdevil will take care of exposing your action only if support for it is advertised. In addition,
  * the UI will expose the configuration of your action only if its support is advertised. Of course, this means the
  * action will be temporarily loaded by the config UI to verify its support. If your action is performing some tasks in
- * the constructor besides setting policies, first of all revise your design since you probably don't need or want to
- * do that. If you really cannot avoid that, you MUST check for an OPTIONAL parameter in the QVariantList coming
- * from the plugin's constructor. If it exists, it's a boolean and it is true, the action is being loaded just for
- * a support check, and you should refrain from doing any actions which would affect the system. This parameter is also
- * used in tests.
+ * the constructor besides setting policies, revise your design since you probably don't need or want to do that.
  *
  * @par Handling policies from within the action
  *
@@ -98,7 +76,7 @@ class Core;
  *
  * @since 4.6
  */
-class Q_DECL_EXPORT Action : public QObject
+class POWERDEVILCORE_EXPORT Action : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(Action)
@@ -115,21 +93,19 @@ public:
 
     /**
      * Reimplement this function when creating a new Action. This function is called whenever the action is loaded or
-     * its configuration changes. It carries the KConfigGroup associated with your action and generated from your
-     * config interface.
+     * its configuration changes. It carries the ProfileSettings associated with the active power management
+     * profile and generated from your config interface.
      *
-     * @param config The action's configuration which should be loaded.
-     * @returns Whether the action has been successfully loaded.
+     * @param profileSettings The profile settings containing the action's configuration which should be loaded.
+     * @returns Whether the action has been successfully loaded. Should return false if not enabled for the given @p profileSettings.
      *
      * @see ActionConfig
      */
-    virtual bool loadAction(const KConfigGroup &config) = 0;
+    virtual bool loadAction(const PowerDevil::ProfileSettings &profileSettings) = 0;
     /**
-     * Unloads the action. You usually shouldn't reimplement this function: reimplement onUnloadAction instead.
-     *
-     * @returns Whether the action has been successfully unloaded
+     * Unloads the action.
      */
-    virtual bool unloadAction();
+    void unloadAction();
 
     /**
      * This function is meant to find out if this action is available on this system. Actions
@@ -155,10 +131,8 @@ protected:
      * Registers an idle timeout for this action. Call this function and not KIdleTime directly to take advantage
      * of Action's automated handling of idle timeouts. Also, please reimplement onIdleTimeout instead of listening
      * to KIdleTime's signals to catch idle timeout events.
-     *
-     * @param msec The idle timeout to be registered in milliseconds.
      */
-    void registerIdleTimeout(int msec);
+    void registerIdleTimeout(std::chrono::milliseconds timeout);
     /**
      * Sets the required policies needed for this Action to run. Usually, you want to call this function in your
      * Action's constructor.
@@ -190,41 +164,30 @@ protected Q_SLOTS:
      * loadAction: in fact a profile can be reloaded without having the action change its configuration.
      * If your action should do something as soon as a profile switches, it should be done inside this function.
      */
-    virtual void onProfileLoad() = 0;
+    virtual void onProfileLoad(const QString &previousProfile, const QString &newProfile);
     /**
      * This slot is triggered whenever an idle timeout registered with registerIdleTimeout is reached.
      *
-     * @param msec The idle timeout reached in milliseconds
+     * @param timeout The idle timeout reached
      */
-    virtual void onIdleTimeout(int msec) = 0;
+    virtual void onIdleTimeout(std::chrono::milliseconds timeout);
     /**
      * This slot is triggered whenever the PC wakes up from an Idle state. It is @b always called after a registered
      * idle timeout has been reached.
      */
-    virtual void onWakeupFromIdle() = 0;
+    virtual void onWakeupFromIdle();
     /**
      * This function is called when the profile is unloaded.
      */
-    virtual void onProfileUnload() = 0;
-    /**
-     * This function is called when the action is unloaded. You usually want to put what would have gone in your
-     * destructor here.
-     *
-     * @returns Whether the action was unloaded successfully.
-     */
-    virtual bool onUnloadAction();
-
-Q_SIGNALS:
-    void actionTriggered(bool result, const QString &error = QString());
+    virtual void onProfileUnload();
 
 private:
-    class Private;
-    Private * const d;
+    PowerDevil::Core *m_core;
+
+    QList<std::chrono::milliseconds> m_registeredIdleTimeouts;
+    PowerDevil::PolicyAgent::RequiredPolicies m_requiredPolicies;
 
     friend class Core;
-    friend class ActionPool;
 };
 
 }
-
-#endif // POWERDEVIL_POWERDEVILACTION_H
