@@ -1,31 +1,18 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
-
-#ifndef POWERDEVIL_POWERDEVILACTIONCONFIG_H
-#define POWERDEVIL_POWERDEVILACTIONCONFIG_H
+#pragma once
 
 #include <QWidget>
 
-#include <KConfigGroup>
+#include "powerdevilcore_export.h"
 
-namespace PowerDevil {
+namespace PowerDevil
+{
+class ProfileSettings;
 
 /**
  * @brief The base class for Action's config interfaces
@@ -51,15 +38,16 @@ namespace PowerDevil {
  * @par Loading and saving configuration
  *
  * Of course, you should also be providing the logic for saving and loading your action's configuration.
- * This is done through KConfigGroup: your action has a KConfigGroup assigned by KDE Power Management System
- * which can be accessed through configGroup or overwritten through setConfigGroup. The very same group
- * you are loading/saving here will be the one passed to Action::loadAction.
+ * This is done through PowerDevil::ProfileSettings: your action should have corresponding entries in
+ * PowerDevil::ProfileSettings which is provided by the KDE Power Management System and accessible
+ * to an ActionConfig via profileSettings(). The very same settings data you are loading/saving here
+ * will be the one passed to Action::loadAction.
  *
  * @see Action
  *
  * @since 4.6
  */
-class Q_DECL_EXPORT ActionConfig : public QObject
+class POWERDEVILCORE_EXPORT ActionConfig : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(ActionConfig)
@@ -75,40 +63,55 @@ public:
     ~ActionConfig() override;
 
     /**
-     * @returns The KConfigGroup associated to this action, where data should be saved (and loaded)
+     * @returns The ProfileSettings associated with this profile, where data should be saved (and loaded from)
      *
-     * @note You should not track this KConfigGroup, as it might change from profile to profile.
+     * @note You should not track this ProfileSettings, as it might change from profile to profile.
      *       Always use this function to access it.
      */
-    KConfigGroup configGroup() const;
+    PowerDevil::ProfileSettings *profileSettings() const;
     /**
-     * Overwrites the config group associated with this Action with @c group.
+     * Overwrites the profile settings object associated with this profile with @c settings.
      *
-     * @param group A KConfigGroup carrying the settings for this Action.
+     * @param settings A ProfileSettings carrying the settings for this profile. (No ownership transfer.)
      */
-    void setConfigGroup(const KConfigGroup &group);
+    void setProfileSettings(PowerDevil::ProfileSettings *settings);
 
     /**
      * This function should return the key/value pairs containing your Action's configuration UI.
      *
      * @returns A list of QString, QWidget pairs representing your Action's configuration UI
      */
-    virtual QList< QPair< QString, QWidget* > > buildUi() = 0;
+    virtual QList<QPair<QString, QWidget *>> buildUi() = 0;
 
     /**
      * This function gets called whenever the parent module requires to load a specific configuration. This
-     * usually occurs when @c configGroup is updated, for example due to the fact that the user wants to modify
+     * usually occurs when @c profileSettings is updated, for example due to the fact that the user wants to modify
      * a different profile. In this function, you should update the info contained in the widgets generated
      * by @c buildUi accordingly.
      */
     virtual void load() = 0;
     /**
      * This function gets called whenever the parent module requires to save the configuration. Usually, you
-     * want to read values from the widgets generated with @c buildUi and call @c setConfigGroup to update the
-     * Action's configuration.
+     * want to read values from the widgets generated with @c buildUi and call setter functions on @c profileSettings
+     * to update the Action's configuration. The Action does not need to call save() on @c profileSettings by itself,
+     * that is the responsibility of the parent module.
      */
     virtual void save() = 0;
 
+    /**
+     * @returns The action-specific value from @c profileSettings that tells whether the action is enabled for this profile.
+     *
+     * @note The parent module can use this to update the checkbox associated with the action's config section.
+     */
+    virtual bool enabledInProfileSettings() const = 0;
+
+    /**
+     * This function gets called by the parent module to let the ActionConfig set in @c profileSettings
+     * whether or not the action is enabled for this profile. This may be called in the same go with save(),
+     * make sure that there is no conflict between values set here and there.
+     */
+    virtual void setEnabledInProfileSettings(bool enabled) = 0;
+
 protected Q_SLOTS:
     /**
      * Call this slot whenever the user makes some changes to the widgets.
@@ -126,9 +129,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 }
-
-#endif // POWERDEVIL_POWERDEVILACTIONCONFIG_H
