@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "powerdevilapp.h"
 
@@ -23,31 +10,34 @@
 #include "powermanagementadaptor.h"
 #include "powermanagementpolicyagentadaptor.h"
 
-#include "powerdevilcore.h"
 #include "powerdevil_debug.h"
 #include "powerdevil_version.h"
+#include "powerdevilcore.h"
+#include "../osd/osd.h"
 
-#include <QTimer>
+#include <QAction>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDebug>
 #include <QFileInfo>
-#include <QAction>
 #include <QKeySequence>
 #include <QSessionManager>
+#include <QTimer>
 
+#include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
-#include <KAboutData>
 #include <KLocalizedString>
 
-#include <kworkspace.h>
+#include <KActionCollection>
+#include <KGlobalAccel>
+
+#include <qnamespace.h>
 
 PowerDevilApp::PowerDevilApp(int &argc, char **argv)
     : QGuiApplication(argc, argv)
     , m_core(nullptr)
 {
-
 }
 
 PowerDevilApp::~PowerDevilApp()
@@ -57,32 +47,29 @@ PowerDevilApp::~PowerDevilApp()
 
 void PowerDevilApp::init()
 {
-    KLocalizedString::setApplicationDomain("powerdevil");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("powerdevil"));
 
-    KAboutData aboutData(QStringLiteral("org_kde_powerdevil"), i18n("KDE Power Management System"), QStringLiteral(POWERDEVIL_VERSION_STRING),
+    KAboutData aboutData(QStringLiteral("org_kde_powerdevil"),
+                         i18n("KDE Power Management System"),
+                         QStringLiteral(POWERDEVIL_VERSION_STRING),
                          i18nc("@title", "PowerDevil, an advanced, modular and lightweight power management daemon"),
                          KAboutLicense::GPL,
                          i18nc("@info:credit", "(c) 2015-2019 Kai Uwe Broulik"));
-    aboutData.addAuthor(i18nc("@info:credit", "Kai Uwe Broulik"),
-                        i18nc("@info:credit", "Maintainer"),
-                        QStringLiteral("kde@privat.broulik.de"));
-    aboutData.addAuthor(i18nc("@info:credit", "Dario Freddi"),
-                        i18nc("@info:credit", "Previous maintainer"),
-                        QStringLiteral("drf@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Kai Uwe Broulik"), i18nc("@info:credit", "Maintainer"), QStringLiteral("kde@privat.broulik.de"));
+    aboutData.addAuthor(i18nc("@info:credit", "Dario Freddi"), i18nc("@info:credit", "Previous maintainer"), QStringLiteral("drf@kde.org"));
     aboutData.setProductName("Powerdevil");
 
     KAboutData::setApplicationData(aboutData);
 
-    if (QDBusConnection::systemBus().interface()->isServiceRegistered(QLatin1String("org.freedesktop.PowerManagement")) ||
-        QDBusConnection::systemBus().interface()->isServiceRegistered(QLatin1String("com.novell.powersave")) ||
-        QDBusConnection::systemBus().interface()->isServiceRegistered(QLatin1String("org.freedesktop.Policy.Power"))) {
+    if (QDBusConnection::systemBus().interface()->isServiceRegistered(QLatin1String("org.freedesktop.PowerManagement"))
+        || QDBusConnection::systemBus().interface()->isServiceRegistered(QLatin1String("org.freedesktop.Policy.Power"))) {
         qCCritical(POWERDEVIL) << "KDE Power Management system not initialized, another power manager has been detected";
         return;
     }
 
     // not parenting Core to PowerDevilApp as it is the deleted too late on teardown
     // where the X connection is already lost leading to a crash (Bug 371127)
-    m_core = new PowerDevil::Core(nullptr/*, KComponentData(aboutData)*/);
+    m_core = new PowerDevil::Core(nullptr /*, KComponentData(aboutData)*/);
 
     connect(m_core, &PowerDevil::Core::coreReady, this, &PowerDevilApp::onCoreReady);
 
@@ -90,15 +77,12 @@ void PowerDevilApp::init()
     const QStringList paths = QCoreApplication::libraryPaths();
     QFileInfoList fileInfos;
     for (const QString &path : paths) {
-        QDir dir(path + QStringLiteral("/kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/powerdevil/"),
-            QStringLiteral("*"),
-            QDir::SortFlags(QDir::QDir::Name),
-            QDir::NoDotAndDotDot | QDir::Files);
+        QDir dir(path + QStringLiteral("/kf6/powerdevil/"), QStringLiteral("*"), QDir::SortFlags(QDir::QDir::Name), QDir::NoDotAndDotDot | QDir::Files);
         fileInfos.append(dir.entryInfoList());
     }
 
     QFileInfo backendFileInfo;
-    for (const QFileInfo &f : qAsConst(fileInfos)) {
+    for (const QFileInfo &f : std::as_const(fileInfos)) {
         if (f.baseName().toLower() == QLatin1String("powerdevilupowerbackend")) {
             backendFileInfo = f;
             break;
@@ -109,14 +93,12 @@ void PowerDevilApp::init()
     QObject *instance = loader->instance();
     if (!instance) {
         qCCritical(POWERDEVIL) << "KDE Power Management System init failed!" << loader->errorString();
-        m_core->loadCore(nullptr);
         return;
     }
 
-    auto interface = qobject_cast<PowerDevil::BackendInterface*>(instance);
+    auto interface = qobject_cast<PowerDevil::BackendInterface *>(instance);
     if (!interface) {
         qCCritical(POWERDEVIL) << "KDE Power Management System init failed! Failed to cast plugin instance to BackendInterface, check your plugin";
-        m_core->loadCore(nullptr);
         return;
     }
 
@@ -127,7 +109,7 @@ void PowerDevilApp::init()
 void PowerDevilApp::onCoreReady()
 {
     qCDebug(POWERDEVIL) << "Core is ready, registering various services on the bus...";
-    //DBus logic for the core
+    // DBus logic for the core
     new PowerManagementAdaptor(m_core);
     new PowerDevil::FdoConnector(m_core);
 
@@ -143,13 +125,18 @@ void PowerDevilApp::onCoreReady()
 
     QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.Solid.PowerManagement.PolicyAgent"));
     QDBusConnection::sessionBus().registerObject(QLatin1String("/org/kde/Solid/PowerManagement/PolicyAgent"), PowerDevil::PolicyAgent::instance());
+
+    KActionCollection *coll = new KActionCollection(this);
+    QAction *action = coll->addAction(QStringLiteral("powerProfile"));
+    action->setText(i18n("Switch Power Profile"));
+    KGlobalAccel::self()->setGlobalShortcut(action, QList<QKeySequence>{Qt::Key_Battery, Qt::MetaModifier | Qt::Key_B});
+    connect(action, &QAction::triggered, this, &PowerDevilApp::showOsd);
 }
 
 int main(int argc, char **argv)
 {
     QGuiApplication::setDesktopSettingsAware(false);
     QGuiApplication::setAttribute(Qt::AA_DisableSessionManager);
-    KWorkSpace::detectPlatform(argc, argv);
     PowerDevilApp app(argc, argv);
 
     bool replace = false;
@@ -171,7 +158,18 @@ int main(int argc, char **argv)
     KCrash::setFlags(KCrash::AutoRestart);
 
     app.setQuitOnLastWindowClosed(false);
+    app.setQuitLockEnabled(false);
     app.init();
 
     return app.exec();
 }
+
+void PowerDevilApp::showOsd() {
+    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.powerdevil.powerProfileOsdService"),
+                                                          QStringLiteral("/org/kde/powerdevil/powerProfileOsdService"),
+                                                          QStringLiteral("org.kde.powerdevil.powerProfileOsdService"),
+                                                          QStringLiteral("showOsd"));
+    QDBusConnection::sessionBus().asyncCall(message);
+}
+
+#include "moc_powerdevilapp.cpp"
