@@ -1,31 +1,15 @@
-/***************************************************************************
- *   Copyright (C) 2014 by Nikita Skovoroda <chalkerx@gmail.com>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Nikita Skovoroda <chalkerx@gmail.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
+#pragma once
 
-#ifndef POWERDEVIL_BRIGHTNESSLOGIC_H
-#define POWERDEVIL_BRIGHTNESSLOGIC_H
-
-namespace PowerDevil {
-
+namespace PowerDevil
+{
 class BrightnessLogic
 {
-
 public:
     BrightnessLogic();
     virtual ~BrightnessLogic() = default;
@@ -36,8 +20,16 @@ public:
      * - Increase: Key to increase brightness (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp)
      * - Decrease: Key to decrease brightness (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown)
      * - Toggle: Key to toggle backlight (Qt::Key_KeyboardBacklightOnOff)
+     * - IncreaseSmall: Key to increase brightness by 1% (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp + Qt::ShiftModifier)
+     * - DecreaseSmall: Key to decrease brightness by 1% (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown + Qt::ShiftModifier)
      */
-    enum BrightnessKeyType { Increase, Decrease, Toggle };
+    enum BrightnessKeyType {
+        Increase,
+        Decrease,
+        Toggle,
+        IncreaseSmall,
+        DecreaseSmall,
+    };
 
     /**
      * This struct contains information about current brightness state for a single device
@@ -47,6 +39,8 @@ public:
         int value;
         /** The maximum possible brightness value for this device */
         int valueMax;
+        /** The most recent brightness before toggling off */
+        int valueBeforeTogglingOff;
         /** The maximum possible brightness step for this device */
         int steps;
     };
@@ -65,6 +59,13 @@ public:
      */
     void setValueMax(int valueMax);
 
+    /**
+     * Sets the last active brightness value.
+     *
+     * @param value Last active brightness value
+     */
+    void setValueBeforeTogglingOff(int valueBeforeTogglingOff);
+
     /**
      * Calculate new brightness value that should be set by an action.
      *
@@ -79,7 +80,7 @@ public:
      *
      * @return The brightness value of the closest step upwards
      */
-    virtual int increased() const;
+    int increased() const;
 
     /**
      * Calculates the brightness value of the closest step downwards.
@@ -87,36 +88,31 @@ public:
      *
      * @return The brightness value of the closest step downwards
      */
-    virtual int decreased() const;
+    int decreased() const;
 
     /**
      * Calculates the brightness value of the toggled state.
-     * (Sets the brightness value to either 0 or valueMax).
+     * (Sets the brightness value to either minimum, last active brightness or maximum).
      *
      * @return The brightness value that should be set, or -1 if nothing should be done
      */
     virtual int toggled() const;
 
     /**
-     * Retrieve the current brightness value.
+     * Calculates the brightness value of the closest step upwards.
+     * (Closest step that is higher than current brightness value).
      *
-     * @return Raw brightness value, from 0 to valueMax
+     * @return The brightness value of the closest step upwards
      */
-    int value() const;
+    int increasedSmall() const;
 
     /**
-     * Retrieve the maximum possible brightness value for this device.
+     * Calculates the brightness value of the closest step downwards.
+     * (Closest step that is lower than current brightness value).
      *
-     * @return Maximum possible brightness value
+     * @return The brightness value of the closest step downwards
      */
-    int valueMax() const;
-
-    /**
-     * Retrieve the brightness step that is closest to the current brightness value.
-     *
-     * @return Nearest brightness step
-     */
-    int step() const;
+    int decreasedSmall() const;
 
     /**
      * Retrieve the maximum possible brightness step for this instance
@@ -149,15 +145,20 @@ public:
     int stepToValue(int step) const;
 
     /**
-     * Convert raw brightness value to brightness step
+     * Retrieve the minimum practical brightness value for this device. Defaults
+     * to 0, but should be overridden in subclasses to be a higher value for device
+     * types where a higher minimum value brightness makes sense. For example,
+     * for screens where a value of 0 sometimes turns off the backlight completely,
+     * which is not wanted there.
      *
-     * @param value Brightness value, from 0 to valueMax
-     * @return Brightness step that is nearest to the given brightness value
+     * @return Minimum practical brightness value
      */
-    int valueToStep(int value) const;
+    virtual int valueMin() const
+    {
+        return 0;
+    }
 
 protected:
-
     /**
      * Calculate the optimal number of brightness steps.
      *
@@ -176,9 +177,8 @@ protected:
 private:
     int m_value = -1;
     int m_valueMax = -1;
+    int m_valueBeforeTogglingOff = -1;
     int m_steps = -1;
 };
 
 }
-
-#endif // POWERDEVIL_BRIGHTNESSLOGIC_H
