@@ -1,79 +1,55 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Dario Freddi <drf@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2008 Dario Freddi <drf@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "GeneralPage.h"
 
 #include "ErrorOverlay.h"
-#include "PowerDevilSettings.h"
+#include "PowerButtonActionModel.h"
 
-#include "actions/bundled/suspendsession.h"
-
-#include "powerdevilpowermanagement.h"
+#include <PowerDevilGlobalSettings.h>
+#include <powerdevilenums.h>
+#include <powerdevilpowermanagement.h>
 
+#include <Solid/Battery>
 #include <Solid/Device>
 #include <Solid/DeviceInterface>
-#include <Solid/Battery>
 
-#include <QDBusMessage>
-#include <QDBusReply>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QDBusMessage>
 #include <QDBusMetaType>
+#include <QDBusReply>
 #include <QDBusServiceWatcher>
 
+#include <KAboutData>
+#include <KLocalizedString>
 #include <KNotifyConfigWidget>
 #include <KPluginFactory>
 #include <KSharedConfig>
-#include <KAboutData>
-#include <KLocalizedString>
 
-#include <kauth_version.h>
 #include <KAuth/Action>
 #include <KAuth/ExecuteJob>
+#include <kauth_version.h>
 
 K_PLUGIN_CLASS_WITH_JSON(GeneralPage, "kcm_powerdevilglobalconfig.json")
 
-GeneralPage::GeneralPage(QWidget *parent, const QVariantList &args)
-        : KCModule(parent, args)
+GeneralPage::GeneralPage(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
+    , m_settings(
+          new PowerDevil::GlobalSettings(PowerDevil::PowerManagement::instance()->canSuspend(), PowerDevil::PowerManagement::instance()->canHibernate(), this))
 {
     setButtons(Apply | Help);
 
-//     KAboutData *about =
-//         new KAboutData("powerdevilglobalconfig", "powerdevilglobalconfig", ki18n("Global Power Management Configuration"),
-//                        "", ki18n("A global power management configurator for KDE Power Management System"),
-//                        KAboutData::License_GPL, ki18n("(c), 2010 Dario Freddi"),
-//                        ki18n("From this module, you can configure the main Power Management daemon, assign profiles to "
-//                              "states, and do some advanced fine tuning on battery handling"));
-//
-//     about->addAuthor(ki18n("Dario Freddi"), ki18n("Maintainer") , "drf@kde.org",
-//                      "http://drfav.wordpress.com");
-//
-//     setAboutData(about);
-
-    setupUi(this);
+    setupUi(widget());
 
     fillUi();
 
     QDBusServiceWatcher *watcher = new QDBusServiceWatcher("org.kde.Solid.PowerManagement",
                                                            QDBusConnection::sessionBus(),
-                                                           QDBusServiceWatcher::WatchForRegistration |
-                                                           QDBusServiceWatcher::WatchForUnregistration,
+                                                           QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration,
                                                            this);
 
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &GeneralPage::onServiceRegistered);
@@ -97,7 +73,7 @@ void GeneralPage::fillUi()
 
     const auto devices = Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString());
     for (const Solid::Device &device : devices) {
-        const Solid::Battery *b = qobject_cast<const Solid::Battery*> (device.asDeviceInterface(Solid::DeviceInterface::Battery));
+        const Solid::Battery *b = qobject_cast<const Solid::Battery *>(device.asDeviceInterface(Solid::DeviceInterface::Battery));
         if (b->isPowerSupply()) {
             hasPowerSupplyBattery = true;
         } else {
@@ -105,14 +81,14 @@ void GeneralPage::fillUi()
         }
     }
 
-    BatteryCriticalCombo->addItem(QIcon::fromTheme("dialog-cancel"), i18n("Do nothing"), PowerDevil::BundledActions::SuspendSession::None);
-    if (PowerDevil::PowerManagement::instance()->canSuspend()) {
-        BatteryCriticalCombo->addItem(QIcon::fromTheme("system-suspend"), i18nc("Suspend to RAM", "Sleep"), PowerDevil::BundledActions::SuspendSession::ToRamMode);
-    }
-    if (PowerDevil::PowerManagement::instance()->canHibernate()) {
-        BatteryCriticalCombo->addItem(QIcon::fromTheme("system-suspend-hibernate"), i18n("Hibernate"), PowerDevil::BundledActions::SuspendSession::ToDiskMode);
-    }
-    BatteryCriticalCombo->addItem(QIcon::fromTheme("system-shutdown"), i18n("Shut down"), PowerDevil::BundledActions::SuspendSession::ShutdownMode);
+    BatteryCriticalCombo->setModel(new PowerButtonActionModel(BatteryCriticalCombo,
+                                                              PowerDevil::PowerManagement::instance(),
+                                                              {
+                                                                  PowerDevil::PowerButtonAction::NoAction,
+                                                                  PowerDevil::PowerButtonAction::SuspendToRam,
+                                                                  PowerDevil::PowerButtonAction::SuspendToDisk,
+                                                                  PowerDevil::PowerButtonAction::Shutdown,
+                                                              }));
 
     notificationsButton->setIcon(QIcon::fromTheme("preferences-desktop-notification"));
 
@@ -120,17 +96,17 @@ void GeneralPage::fillUi()
 
     connect(notificationsButton, &QAbstractButton::clicked, this, &GeneralPage::configureNotifications);
 
-    connect(lowSpin, SIGNAL(valueChanged(int)), SLOT(changed()));
-    connect(criticalSpin, SIGNAL(valueChanged(int)), SLOT(changed()));
-    connect(lowPeripheralSpin, SIGNAL(valueChanged(int)), SLOT(changed()));
+    connect(lowSpin, &QSpinBox::valueChanged, this, &KCModule::markAsChanged);
+    connect(criticalSpin, &QSpinBox::valueChanged, this, &KCModule::markAsChanged);
+    connect(lowPeripheralSpin, &QSpinBox::valueChanged, this, &KCModule::markAsChanged);
 
-    connect(BatteryCriticalCombo, SIGNAL(currentIndexChanged(int)), SLOT(changed()));
+    connect(BatteryCriticalCombo, &QComboBox::currentIndexChanged, this, &KCModule::markAsChanged);
 
     connect(chargeStartThresholdSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &GeneralPage::markAsChanged);
     connect(chargeStopThresholdSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &GeneralPage::onChargeStopThresholdChanged);
     chargeStopThresholdMessage->hide();
 
-    connect(pausePlayersCheckBox, SIGNAL(stateChanged(int)), SLOT(changed()));
+    connect(pausePlayersCheckBox, &QCheckBox::stateChanged, this, &KCModule::markAsChanged);
 
     if (!hasPowerSupplyBattery) {
         BatteryCriticalLabel->hide();
@@ -153,13 +129,13 @@ void GeneralPage::fillUi()
 
 void GeneralPage::load()
 {
-    lowSpin->setValue(PowerDevilSettings::batteryLowLevel());
-    criticalSpin->setValue(PowerDevilSettings::batteryCriticalLevel());
-    lowPeripheralSpin->setValue(PowerDevilSettings::peripheralBatteryLowLevel());
+    lowSpin->setValue(m_settings->batteryLowLevel());
+    criticalSpin->setValue(m_settings->batteryCriticalLevel());
+    lowPeripheralSpin->setValue(m_settings->peripheralBatteryLowLevel());
 
-    BatteryCriticalCombo->setCurrentIndex(BatteryCriticalCombo->findData(PowerDevilSettings::batteryCriticalAction()));
+    BatteryCriticalCombo->setCurrentIndex(BatteryCriticalCombo->findData(m_settings->batteryCriticalAction()));
 
-    pausePlayersCheckBox->setChecked(PowerDevilSettings::pausePlayersOnSuspend());
+    pausePlayersCheckBox->setChecked(m_settings->pausePlayersOnSuspend());
 
     KAuth::Action action(QStringLiteral("org.kde.powerdevil.chargethresholdhelper.getthreshold"));
     action.setHelperId(QStringLiteral("org.kde.powerdevil.chargethresholdhelper"));
@@ -179,33 +155,33 @@ void GeneralPage::load()
         setChargeThresholdSupported(false);
     }
 
-    Q_EMIT changed(false);
+    setNeedsSave(false);
 }
 
 void GeneralPage::configureNotifications()
 {
-    KNotifyConfigWidget::configure(this, "powerdevil");
+    KNotifyConfigWidget::configure(widget(), "powerdevil");
 }
 
 void GeneralPage::save()
 {
-    PowerDevilSettings::setBatteryLowLevel(lowSpin->value());
-    PowerDevilSettings::setBatteryCriticalLevel(criticalSpin->value());
-    PowerDevilSettings::setPeripheralBatteryLowLevel(lowPeripheralSpin->value());
+    m_settings->setBatteryLowLevel(lowSpin->value());
+    m_settings->setBatteryCriticalLevel(criticalSpin->value());
+    m_settings->setPeripheralBatteryLowLevel(lowPeripheralSpin->value());
 
-    PowerDevilSettings::setBatteryCriticalAction(BatteryCriticalCombo->itemData(BatteryCriticalCombo->currentIndex()).toInt());
+    m_settings->setBatteryCriticalAction(BatteryCriticalCombo->itemData(BatteryCriticalCombo->currentIndex()).toUInt());
 
-    PowerDevilSettings::setPausePlayersOnSuspend(pausePlayersCheckBox->checkState() == Qt::Checked);
+    m_settings->setPausePlayersOnSuspend(pausePlayersCheckBox->checkState() == Qt::Checked);
 
-    PowerDevilSettings::self()->save();
+    m_settings->save();
 
-    if ((m_chargeStartThreshold != -1 && chargeStartThresholdSpin->value() != m_chargeStartThreshold) || (
-                m_chargeStopThreshold != -1 && chargeStopThresholdSpin->value() != m_chargeStopThreshold)) {
+    if ((m_chargeStartThreshold != -1 && chargeStartThresholdSpin->value() != m_chargeStartThreshold)
+        || (m_chargeStopThreshold != -1 && chargeStopThresholdSpin->value() != m_chargeStopThreshold)) {
         KAuth::Action action(QStringLiteral("org.kde.powerdevil.chargethresholdhelper.setthreshold"));
         action.setHelperId(QStringLiteral("org.kde.powerdevil.chargethresholdhelper"));
         action.setArguments({
             {QStringLiteral("chargeStartThreshold"), m_chargeStartThreshold != -1 ? chargeStartThresholdSpin->value() : -1},
-            {QStringLiteral("chargeStopThreshold"), m_chargeStopThreshold != -1 ? chargeStopThresholdSpin->value() : -1}
+            {QStringLiteral("chargeStopThreshold"), m_chargeStopThreshold != -1 ? chargeStopThresholdSpin->value() : -1},
         });
         KAuth::ExecuteJob *job = action.execute();
         job->exec();
@@ -216,14 +192,14 @@ void GeneralPage::save()
     }
 
     // Notify Daemon
-    QDBusMessage call = QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement", "/org/kde/Solid/PowerManagement",
-                                                       "org.kde.Solid.PowerManagement", "refreshStatus");
+    QDBusMessage call =
+        QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement", "/org/kde/Solid/PowerManagement", "org.kde.Solid.PowerManagement", "refreshStatus");
 
     // Perform call
     QDBusConnection::sessionBus().asyncCall(call);
 
     // And now we are set with no change
-    Q_EMIT changed(false);
+    setNeedsSave(false);
 }
 
 void GeneralPage::defaults()
@@ -243,7 +219,7 @@ void GeneralPage::setChargeThresholdSupported(bool supported)
     chargeStopThresholdSpin->setVisible(supported && m_chargeStopThreshold != -1);
 }
 
-void GeneralPage::onServiceRegistered(const QString& service)
+void GeneralPage::onServiceRegistered(const QString &service)
 {
     Q_UNUSED(service);
 
@@ -253,7 +229,7 @@ void GeneralPage::onServiceRegistered(const QString& service)
     }
 }
 
-void GeneralPage::onServiceUnregistered(const QString& service)
+void GeneralPage::onServiceUnregistered(const QString &service)
 {
     Q_UNUSED(service);
 
@@ -261,8 +237,7 @@ void GeneralPage::onServiceUnregistered(const QString& service)
         m_errorOverlay->deleteLater();
     }
 
-    m_errorOverlay = new ErrorOverlay(this, i18n("The Power Management Service appears not to be running."),
-                                      this);
+    m_errorOverlay = new ErrorOverlay(widget(), i18n("The Power Management Service appears not to be running."), widget());
 }
 
 void GeneralPage::onChargeStopThresholdChanged(int threshold)
@@ -271,7 +246,7 @@ void GeneralPage::onChargeStopThresholdChanged(int threshold)
         // Only show message if there is actually a charging or fully charged battery
         const auto devices = Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString());
         for (const Solid::Device &device : devices) {
-            const Solid::Battery *b = qobject_cast<const Solid::Battery*>(device.asDeviceInterface(Solid::DeviceInterface::Battery));
+            const Solid::Battery *b = qobject_cast<const Solid::Battery *>(device.asDeviceInterface(Solid::DeviceInterface::Battery));
             if (b->chargeState() == Solid::Battery::Charging || b->chargeState() == Solid::Battery::FullyCharged) {
                 chargeStopThresholdMessage->animatedShow();
                 break;
@@ -285,3 +260,5 @@ void GeneralPage::onChargeStopThresholdChanged(int threshold)
 }
 
 #include "GeneralPage.moc"
+
+#include "moc_GeneralPage.cpp"
